==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/lt_LT.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarai",
    "Unknown user" : "Nežinomas naudotojas",
    "New comment …" : "Naujas komentaras …",
    "Delete comment" : "Ištrinti komentarą",
    "Post" : "Įrašas",
    "Cancel" : "Atsisakyti",
    "Edit comment" : "Redaguoti komentarą",
    "[Deleted user]" : "[Ištrintas naudotojas]",
    "No comments yet, start the conversation!" : "Kol kas komentarų nėra, pradėkite pokalbį!",
    "More comments …" : "Daugiau komentarų …",
    "Save" : "Įrašyti",
    "Allowed characters {count} of {max}" : "Leidžiama simbolių {count} iš {max}",
    "Error occurred while retrieving comment with id {id}" : "Klaida bandant parodyti komentarą pagal identifikavimo numerį {id}",
    "Error occurred while updating comment with id {id}" : "Klaida bandant pataisyti komentarą pagal identifikavimo numerį {id}",
    "Error occurred while posting comment" : "Skelbiant komentarą, įvyko klaida",
    "_%n unread comment_::_%n unread comments_" : ["%n neskaitytas komentaras","%n neskaityti komentarai","%n neskaitytų komentarų"],
    "Comment" : "Komentaras",
    "You commented" : "Jūs pakomentavote",
    "%1$s commented" : "%1$s pakomentavo",
    "{author} commented" : "{author} pakomentavo",
    "You commented on %1$s" : "Pakomentavote %1$s",
    "You commented on {file}" : "Pakomentavote {file}",
    "%1$s commented on %2$s" : "%1$s pakomentavo %2$s",
    "{author} commented on {file}" : "{author} pakomentavo {file}",
    "<strong>Comments</strong> for files" : "<strong>Failų komentarai</strong>",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Ištrintas vartotojas paminėjo jus komentare \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Ištrintas vartotojas paminėjo jus komentare \"{file}\"",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s paminėjo jus komentare \"%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} paminėjo jus komentare “{file}”"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/lt_LT.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentarai",
    "Unknown user" : "Nežinomas naudotojas",
    "New comment …" : "Naujas komentaras …",
    "Delete comment" : "Ištrinti komentarą",
    "Post" : "Įrašas",
    "Cancel" : "Atsisakyti",
    "Edit comment" : "Redaguoti komentarą",
    "[Deleted user]" : "[Ištrintas naudotojas]",
    "No comments yet, start the conversation!" : "Kol kas komentarų nėra, pradėkite pokalbį!",
    "More comments …" : "Daugiau komentarų …",
    "Save" : "Įrašyti",
    "Allowed characters {count} of {max}" : "Leidžiama simbolių {count} iš {max}",
    "Error occurred while retrieving comment with id {id}" : "Klaida bandant parodyti komentarą pagal identifikavimo numerį {id}",
    "Error occurred while updating comment with id {id}" : "Klaida bandant pataisyti komentarą pagal identifikavimo numerį {id}",
    "Error occurred while posting comment" : "Skelbiant komentarą, įvyko klaida",
    "_%n unread comment_::_%n unread comments_" : ["%n neskaitytas komentaras","%n neskaityti komentarai","%n neskaitytų komentarų"],
    "Comment" : "Komentaras",
    "You commented" : "Jūs pakomentavote",
    "%1$s commented" : "%1$s pakomentavo",
    "{author} commented" : "{author} pakomentavo",
    "You commented on %1$s" : "Pakomentavote %1$s",
    "You commented on {file}" : "Pakomentavote {file}",
    "%1$s commented on %2$s" : "%1$s pakomentavo %2$s",
    "{author} commented on {file}" : "{author} pakomentavo {file}",
    "<strong>Comments</strong> for files" : "<strong>Failų komentarai</strong>",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s paminėjo jus komentare \"%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} paminėjo jus komentare “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Ištrintas vartotojas paminėjo jus komentare \"%s\"",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Ištrintas vartotojas paminėjo jus komentare \"{file}\""
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
